@@ -23,7 +23,6 @@ the peakrdl command line tool. However, when developing and debugging it is conv
 peakrdl and call the exporter directly.
 """
 
-import os
 import time
 import argparse
 import pathlib
@@ -67,14 +66,14 @@ CommandLineParser.add_argument('--suppress_cleanup', action='store_true', dest='
                                     'files found in the directory where the package will be'
                                     ' generated. This is normally useful if the user is '
                                     'generating over the top of an existing package and prevents '
-                                    'problems when the strucutre of the register map changes. '
+                                    'problems when the structure of the register map changes. '
                                     'However, if additional python files are added by the user '
                                     '(not recommended) this cleanup will need to be suppressed '
                                     'and managed by the user')
 CommandLineParser.add_argument('--copy_libraries', action='store_true', dest='copy_libraries',
                                help='by default peakrdl python copies all the libraries over'
                                     'to the generated package along with the generated code. '
-                                    'However, that is potententially problematic when developing'
+                                    'However, that is potentiality problematic when developing'
                                     'and debugging as multiple copies of the libraries can cause'
                                     'confusion. Therefore by default this script does not copy '
                                     'them over.')
@@ -92,6 +91,18 @@ CommandLineParser.add_argument('--full_inst_file', dest='full_inst_file',
                                type=pathlib.Path, required=False,
                                help='export a text file with a list of the all qualified instance'
                                     'names in the systemRDL')
+CommandLineParser.add_argument('--legacy_enum_type', action='store_true',
+                               dest='legacy_enum_type',
+                               help='peakrdl python has ways to define field encoding as enums a '
+                                    'a new method and an old method based on IntEnum. Setting '
+                                    'this to true will restore the old behaviour')
+CommandLineParser.add_argument('--skip_systemrdl_name_and_desc_properties',
+                               action='store_true',
+                               dest='skip_systemrdl_name_and_desc_properties',
+                               help='peakrdl python includes the system RDL name and desc '
+                                    'attributes as properties of the class that is built. Setting '
+                                    'this will skip this reducign the size of the python code '
+                                    'generated')
 
 
 def build_logging_cong(logfilepath:str):
@@ -179,13 +190,17 @@ if __name__ == '__main__':
 
     exporter = PythonExporter()
     start_time = time.time()
-    exporter.export(node=spec, path=str(CommandLineArgs.output_path / 'generate_and_test_output'),
-                    asyncoutput=CommandLineArgs.asyncoutput,
-                    delete_existing_package_content=not CommandLineArgs.suppress_cleanup,
-                    skip_library_copy=not CommandLineArgs.copy_libraries,
-                    legacy_block_access=CommandLineArgs.legacy_block_access,
-                    user_defined_properties_to_include=CommandLineArgs.udp,
-                    hidden_inst_name_regex=CommandLineArgs.hide_regex)
+    exporter.export(
+        node=spec, path=str(CommandLineArgs.output_path / 'generate_and_test_output'),
+        asyncoutput=CommandLineArgs.asyncoutput,
+        delete_existing_package_content=not CommandLineArgs.suppress_cleanup,
+        skip_library_copy=not CommandLineArgs.copy_libraries,
+        legacy_block_access=CommandLineArgs.legacy_block_access,
+        user_defined_properties_to_include=CommandLineArgs.udp,
+        hidden_inst_name_regex=CommandLineArgs.hide_regex,
+        legacy_enum_type=CommandLineArgs.legacy_enum_type,
+        skip_systemrdl_name_and_desc_properties=
+        CommandLineArgs.skip_systemrdl_name_and_desc_properties)
     print(f'generation time {time.time() - start_time}s')
 
     if not CommandLineArgs.export_only:
@@ -210,7 +225,7 @@ if __name__ == '__main__':
             peakrdl_python_package = __import__('generate_and_test_output.' + CommandLineArgs.root_node + '.lib',
                                                 globals(), locals(), ['CallbackSet'], 0)
         else:
-            peakrdl_python_package = __import__('src.peakrdl_python.lib',
+            peakrdl_python_package = __import__('peakrdl_python.lib',
                                                 globals(), locals(), ['CallbackSet'], 0)
 
         if CommandLineArgs.asyncoutput is True:
